@@ -3,7 +3,9 @@
 #include <string.h>
 #include <assert.h>
 #include <unistd.h>
+#ifndef __MINGW32__
 #include <sys/mman.h>
+#endif
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -184,7 +186,7 @@ unsigned short * _global_retrieve_big_margin_ptr(global_context_t * global_conte
 
 
 void bigtable_release_result(global_context_t * global_context , thread_context_t * thread_context , subread_read_number_t pair_number, int commit_change){
-	assert(NULL == "File result cache is no longer used. Do not call this function!");
+	assert(NULL == "File result cache is no longer used. Do not call this function.");
 }
 
 
@@ -261,7 +263,7 @@ void bktable_append(bucketed_table_t * tab, char * chro, unsigned int pos, void
 		unsigned int curr_key_pos = twokeys[keyi];
 		if(curr_key_pos == 0xffffffff) continue;
 
-		sprintf(static_key, "%s:%u", chro, curr_key_pos);
+		SUBreadSprintf(static_key, 20 + MAX_CHROMOSOME_NAME_LEN, "%s:%u", chro, curr_key_pos);
 
 		bucketed_table_bucket_t * had_items = HashTableGet(tab -> entry_table, static_key);
 
@@ -315,7 +317,7 @@ int bktable_lookup(bucketed_table_t * tab, char * chro, unsigned int start_pos,
 	my_key_pos = start_pos - start_pos % tab -> maximum_interval_length;
 
 	char static_key [20 + MAX_CHROMOSOME_NAME_LEN];
-	sprintf(static_key, "%s:%u", chro, my_key_pos);
+	SUBreadSprintf(static_key, 20 + MAX_CHROMOSOME_NAME_LEN, "%s:%u", chro, my_key_pos);
 
 	bucketed_table_bucket_t * had_items = HashTableGet(tab -> entry_table, static_key);
 
