@@ -20,8 +20,8 @@ int max_M = 10;
 int paired_end = 0;
 int ignore_bad_pair = 0;
 int base_values = 0;
-char input_file_name[300];
-char output_file_name[300];
+char input_file_name[MAX_FILE_NAME_LENGTH];
+char output_file_name[MAX_FILE_NAME_LENGTH];
 HashTable * cov_bin_table;
 
 
