@@ -485,21 +485,21 @@ int iCache_continuous_read_lanes( cache_BCL_t * cache_input, int bcl_no){
 						tfp -> digit4_to_compressed_start_of_next = HashTableCreate(100); 
 						tfp -> list_mapped_qscore = ArrayListCreate(80); 
 						lseek(tfp -> cbcl_bin_fd, 6, SEEK_CUR);// ver and header_size. Not needed.
-						int btmp = 0, ii;
-						read(tfp -> cbcl_bin_fd,&btmp,1);// bits per call.
+						int btmp = 0, ii, rrv;
+						rrv=read(tfp -> cbcl_bin_fd,&btmp,1);// bits per call.
 						tfp -> bits_per_bitscore = 0;
-						read(tfp -> cbcl_bin_fd,&tfp -> bits_per_bitscore,1);// bits per qscore.
+						rrv+=read(tfp -> cbcl_bin_fd,&tfp -> bits_per_bitscore,1);// bits per qscore.
 						if((tfp -> bits_per_bitscore != 2 && tfp -> bits_per_bitscore != 6) || btmp != 2){
 							SUBREADprintf("Bitwidth of calls unsupported %d %d!\n" , tfp -> bits_per_bitscore, btmp);
 							cache_input -> last_chunk_in_cache = 1;
 							break;
 						}
 						btmp = 0;
-						read(tfp -> cbcl_bin_fd,&btmp,4);// Number of bins 
+						rrv+=read(tfp -> cbcl_bin_fd,&btmp,4);// Number of bins 
 						for(ii=0; ii<btmp; ii++){
 							int fromv=0, tov=0;
-							read(tfp -> cbcl_bin_fd,&fromv,4);
-							read(tfp -> cbcl_bin_fd,&tov,4);
+							rrv+=read(tfp -> cbcl_bin_fd,&fromv,4);
+							rrv+=read(tfp -> cbcl_bin_fd,&tov,4);
 							if(fromv != tfp -> list_mapped_qscore->numOfElements){
 								SUBREADprintf("ERROR: # bits of calls unsupported %d %d!\n" , tfp -> bits_per_bitscore, btmp);
 								cache_input -> last_chunk_in_cache = 1;
@@ -508,20 +508,21 @@ int iCache_continuous_read_lanes( cache_BCL_t * cache_input, int bcl_no){
 							ArrayListPush(tfp -> list_mapped_qscore, NULL+tov);
 						}
 						btmp = 0;
-						read(tfp -> cbcl_bin_fd,&btmp,4);// Number of tiles (gzipped blocks) in this file 
+						rrv+=read(tfp -> cbcl_bin_fd,&btmp,4);// Number of tiles (gzipped blocks) in this file 
 						srInt_64 seek_start = lseek(tfp -> cbcl_bin_fd, 0 , SEEK_CUR) + 1 + 16*btmp; 
 						for(ii=0; ii<btmp; ii++){
 							int tile_4digit=0, reads_in_tile=0, data_size=0, compressed_size=0;
-							read(tfp -> cbcl_bin_fd,&tile_4digit,4);
-							read(tfp -> cbcl_bin_fd,&reads_in_tile,4);
-							read(tfp -> cbcl_bin_fd,&data_size,4);
-							read(tfp -> cbcl_bin_fd,&compressed_size,4);
+							rrv+=read(tfp -> cbcl_bin_fd,&tile_4digit,4);
+							rrv+=read(tfp -> cbcl_bin_fd,&reads_in_tile,4);
+							rrv+=read(tfp -> cbcl_bin_fd,&data_size,4);
+							rrv+=read(tfp -> cbcl_bin_fd,&compressed_size,4);
 							seek_start += compressed_size;
 							HashTablePut(tfp -> digit4_to_compressed_start_of_next, NULL+tile_4digit, NULL+seek_start);
 							HashTablePut(tfp -> digit4_to_total_read_no_P1, NULL+tile_4digit, NULL+1+reads_in_tile);
 						}
 						btmp = 0;
-						read(tfp -> cbcl_bin_fd,&btmp,1); // excluding non-FP?
+						rrv+=read(tfp -> cbcl_bin_fd,&btmp,1); // excluding non-FP?
+						if(rrv<1) break;
 						tfp -> cbcl_only_has_good_reads = btmp;
 					}
 
@@ -1027,6 +1028,7 @@ HashTable * input_BLC_parse_SampleSheet(char * fname){
 ArrayList * input_BLC_parse_CellBarcodes(char * fname){
 	autozip_fp fp;
 	int resop = autozip_open(fname, &fp);
+	//SUBREADprintf("TRY open barcode fp: '%s'  having %p\n", fname, resop);
 	if(resop<0) return NULL;
 
 	ArrayList * ret = ArrayListCreate(10000000);
@@ -1036,9 +1038,10 @@ ArrayList * input_BLC_parse_CellBarcodes(char * fname){
 		char tmp_fl[MAX_BARCODE_LEN+1];
 		int skr = autozip_gets(&fp, tmp_fl, MAX_BARCODE_LEN);
 		if(skr<1) break;
-		//if(ret -> numOfElements <40) SUBREADprintf("LOAD_CELL_BAR : %s , %d\n", tmp_fl, skr);
 		int x1;
 		if(tmp_fl[skr-1]=='\n') tmp_fl[skr-1]=0;
+
+		//if(ret -> numOfElements <40) SUBREADprintf("LOAD_CELL_BAR : %s , %d\n", tmp_fl, skr);
 		for(x1=0; tmp_fl[x1]; x1++) if(!isalpha(tmp_fl[x1])){
 			tmp_fl[x1]=0;
 			break;
@@ -1120,7 +1123,7 @@ int hamming_dist_ATGC_max2(char* s1, char* s2 ){
 
 void iCache_write_supIdx_result(void* ky, void* va, HashTable* tab){
 	FILE * ofp = tab -> appendix1;
-	fprintf(ofp, "%s\t%lld\n", ky, va-NULL);
+	fprintf(ofp, "%s\t%d\n", (char*)ky, (int)(va-NULL));
 }
 void iCache_copy_sample_table_2_list(void* ky, void* va, HashTable* tab){
 	ArrayList * cbclist = tab -> appendix1;
@@ -1758,7 +1761,7 @@ int input_mFQ_init_by_one_string(input_mFQ_t * fqs_input, char * three_paired_fq
 
 }
 
-int input_mFQ_init( input_mFQ_t * fqs_input, char ** files1, char ** files2, char** files3, int total_files ){
+int input_mFQ_init(input_mFQ_t * fqs_input, char ** files1, char ** files2, char** files3, int total_files ){
 	int x1;
 	memset(fqs_input, 0, sizeof(input_mFQ_t));
 	fqs_input->files1 = malloc(sizeof(char*)*total_files);
