@@ -32,6 +32,7 @@
 #define GENE_INPUT_BCL   3
 #define GENE_INPUT_SCRNA_FASTQ 4
 #define GENE_INPUT_SCRNA_BAM 5
+#define GENE_INPUT_CBCL  6
 #define GENE_INPUT_GZIP_FASTQ 51
 #define GENE_INPUT_GZIP_FASTA 52
 
@@ -102,9 +103,9 @@ typedef struct {
 	unsigned int readno_in_chunk;
 
 	unsigned char * input_buff_BIN;
-	int input_buff_BIN_used;
-	int input_buff_BIN_ptr;
-	int input_buff_BIN_capacity;
+	unsigned int input_buff_BIN_used;
+	unsigned int input_buff_BIN_ptr;
+	unsigned int input_buff_BIN_capacity;
 	int orphant_block_no;
 	int need_find_start;
 	srInt_64 orphant_space;
@@ -125,10 +126,10 @@ typedef struct {
 	int input_is_BAM;
 	int tiny_mode;
 	int display_progress;
-	int is_bad_format;
+	int format_need_fixing;
 	int is_single_end_mode;
 	int force_do_not_sort;
-	int long_cigar_mode;
+	int using_long_read_parser;
 	int long_read_minimum_length;
 	int is_finished;
 	int merge_level_finished;
@@ -146,8 +147,8 @@ typedef struct {
 
 	int total_threads;
 	int input_chunk_no;
-	int input_buff_SBAM_size;
-	int input_buff_BIN_size;
+	unsigned int input_buff_SBAM_size;
+	unsigned int input_buff_BIN_size;
 	char tmp_file_prefix[MAX_FILE_NAME_LENGTH+1];
 	char in_file_name[MAX_FILE_NAME_LENGTH+1];
 
