@@ -116,7 +116,7 @@ int main_read_repair(int argc, char ** argv)
 	char mac_rand[13];
 	mac_or_rand_str(mac_rand);
 
-	sprintf(rand_prefix, "fsbm-p%06d-%s", getpid(), mac_rand);
+	SUBreadSprintf(rand_prefix, 40, "fsbm-p%06d-%s", getpid(), mac_rand);
 
 	SAM_pairer_context_t pairer;
 	SAM_pairer_writer_main_t writer_main;
@@ -131,12 +131,12 @@ int main_read_repair(int argc, char ** argv)
 			return -1;
 		}else{
 			SAM_pairer_run(&pairer);
-			int has_error = pairer.is_bad_format;
+			int has_error = pairer.format_need_fixing;
 			SAM_pairer_destroy(&pairer);
 			SAM_pairer_writer_destroy(&writer_main);
 			SUBREADprintf("\n%s %.2f minutes\nTotal input reads: %llu ; Unpaired reads: %llu\n\n", has_error?"Program terminated WITH ERRORS!!! Used":"All finished in", (miltime()-t0)/60, pairer.total_input_reads, pairer.total_orphan_reads);
 			if(has_error){
-				SUBREADprintf("No output file was generated!!!\n");
+				SUBREADprintf("No output file was generated.\n");
 				unlink(out_BAM_file);
 				return -1;
 			}
