@@ -25,7 +25,6 @@ void seekgz_try_read_some_zipped_data(seekable_zfile_t * fp, int * is_eof){
 		return;
 	}
 
-	assert(fp -> stem.avail_in >= 0);
 	if(fp -> stem.avail_in < SEEKGZ_BINBUFF_SIZE / 2 ) {
 		if(fp -> in_zipped_buff_read_ptr > 0 && fp -> stem.avail_in > 0){
 			int i;
@@ -301,6 +300,7 @@ int seekgz_load_1_block( seekable_zfile_t * fp , int empty_block_no){
 		while(1){
 			seekgz_try_read_some_zipped_data(fp, &is_eof);
 			if(fp -> stem.avail_in < 1 && is_eof)break;
+			if(fp -> stem.avail_in < 1) continue;
 
 			if(out_txt_size < out_txt_used *4/3){
 				out_txt_size *= 2;
@@ -313,17 +313,13 @@ int seekgz_load_1_block( seekable_zfile_t * fp , int empty_block_no){
 
 			void * old_next_in = fp -> stem.next_in;
 				
-				//SUBREADprintf("i  INFLATINHG: FILEPOS=%llu  IN_AVAIL=%d  OUT_AVAIL=%d\n", seekgz_ftello(fp), fp -> stem.avail_in, fp -> stem.avail_out);
 			int ret_ifl = inflate(&(fp -> stem), Z_BLOCK);
 			int have = (out_txt_size - out_txt_used) - fp -> stem.avail_out;
 			if(ret_ifl != Z_OK && ret_ifl != Z_STREAM_END){
-				SUBREADprintf("ERR  INFLATINHG: RET=%d BY IN %d zipped bytes  ==>  %d PLAIN TXT\n", ret_ifl, old_avail_in - fp -> stem.avail_in, have);
+				SUBREADprintf("ERR  INFLATINHG: RET=%d BY IN %d (%d - %d) zipped bytes  ==>  %d PLAIN TXT\n", ret_ifl, old_avail_in - fp -> stem.avail_in, old_avail_in, fp -> stem.avail_in, have);
 				SUBREADprintf("ERR  INFLATINHG: BEND=%d\n", ( fp -> stem.data_type & 128 )&& !(fp -> stem.data_type & 64));
 			}
 
-			//if(ret_ifl != Z_STREAM_END){
-			//	SUBREADprintf("INF: STREAM_END\n");
-			//}
 			if(ret_ifl != Z_OK && ret_ifl != Z_STREAM_END){
 				is_data_error = 1;
 				break;
@@ -334,11 +330,7 @@ int seekgz_load_1_block( seekable_zfile_t * fp , int empty_block_no){
 			if( ( fp -> stem.data_type & 128 )&& !(fp -> stem.data_type & 64)) is_block_end = 1;
 			if(ret_ifl == Z_STREAM_END) is_gzip_unit_end = 1;
 
-			//if(is_block_end)
-			//	fp -> rolling_dict_window_used = 0;
-			//else
 			seekgz_update_current_window(fp, out_txt + out_txt_used, have);
-
 			out_txt_used += have;
 
 			if(is_block_end){
@@ -562,6 +554,7 @@ void seekgz_close(seekable_zfile_t * fp){
 
 int autozip_open(const char * fname, autozip_fp * fp){
 	int ret = -1;
+	int need_seek=1;
 	memset(fp, 0, sizeof(autozip_fp));
 	strcpy(fp -> filename, fname);
 
@@ -575,7 +568,13 @@ int autozip_open(const char * fname, autozip_fp * fp){
 	if(cc2 == 0x8b && cc1 == 0x1f){
 		//fclose(tstfp);
 		fp -> is_plain = 0;
-		int iret = seekgz_open(fname, &fp -> gz_fp, tstfp);
+		fp -> zlib_fp = NULL;
+		int iret = 0;
+		if(need_seek) iret = seekgz_open(fname, &fp -> gz_fp, tstfp);
+		else{
+			fp -> zlib_fp = gzopen(fname, "rb");
+			if(fp -> zlib_fp == NULL) iret=-1;
+		}
 		if(iret >= 0) ret = 1;
 		else ret = -1;
 	}else{
@@ -594,8 +593,9 @@ int autozip_open(const char * fname, autozip_fp * fp){
 
 void autozip_close(autozip_fp * fp){
 	if(fp -> is_plain) fclose(fp -> plain_fp);
-	else
-		seekgz_close(&fp -> gz_fp);
+	else if(fp->zlib_fp) gzclose(fp -> zlib_fp);
+	else seekgz_close(&fp -> gz_fp);
+	fp -> plain_fp = NULL;
 } 
 
 int autozip_gets(autozip_fp * fp, char * buf, int buf_size){
@@ -610,12 +610,20 @@ int autozip_gets(autozip_fp * fp, char * buf, int buf_size){
 		}
 		buf[2]=0;
 
-		char * retc = fgets(buf + base0, buf_size, fp -> plain_fp);
-		if(retc == NULL && base0 == 0) ret = 0;
-		else ret = strlen(buf);
+		if(fp -> plain_fp) {
+			char * retc = fgets(buf + base0, buf_size, fp -> plain_fp);
+			if(retc == NULL && base0 == 0) ret = 0;
+			else ret = strlen(buf);
+		}
 	}else{
-		seekgz_preload_buffer(&fp->gz_fp, NULL);
-		ret = seekgz_gets(&fp -> gz_fp, buf, buf_size);
+		if(fp -> zlib_fp){
+			char *rets = gzgets(fp -> zlib_fp, buf, buf_size);
+			if(rets) ret = strlen(buf);
+			else ret = 0;
+		}else{
+			seekgz_preload_buffer(&fp->gz_fp, NULL);
+			ret = seekgz_gets(&fp -> gz_fp, buf, buf_size);
+		}
 	}
 	//SUBREADprintf("READBUF '%s'\n", buf);
 	return ret;
@@ -628,13 +636,18 @@ int autozip_getch(autozip_fp * fp){
 		ret = fgetc(fp -> plain_fp);
 		if(ret==EOF)ret = -1;
 	}else{
-		ret = seekgz_next_int8(&fp -> gz_fp);
+		if(fp -> zlib_fp) ret = gzgetc (fp -> zlib_fp);
+		else ret = seekgz_next_int8(&fp -> gz_fp);
 	}
 	return ret;
 }
 
 void autozip_rewind(autozip_fp * fp){
 	char fname [MAX_FILE_NAME_LENGTH+1];
+	if(fp->zlib_fp){
+		SUBREADprintf("File opened as non-seekable.\n");
+		return;
+	}
 	strcpy(fname, fp -> filename);
 
 	autozip_close(fp);
@@ -665,12 +678,25 @@ void parallel_gzip_writer_init(parallel_gzip_writer_t * pzwtr, char * output_fil
 	pzwtr -> CRC32 = crc32(0, NULL, 0);
 }
 
-void parallel_gzip_writer_add_text(parallel_gzip_writer_t * pzwtr, char * text, int tlen, int thread_no){
-	parallel_gzip_writer_thread_t *tho = pzwtr -> thread_objs + thread_no;
-	if(tlen + tho -> in_buffer_used >= PARALLEL_GZIP_TXT_BUFFER_SIZE){
-		SUBREADprintf("Insufficient gzip buffer.\n");
-		return;
+#define CHECK_SIZE parallel_gzip_writer_thread_t *tho = pzwtr -> thread_objs + thread_no;\
+  if(tlen + tho -> in_buffer_used >= PARALLEL_GZIP_TXT_BUFFER_SIZE){\
+    SUBREADprintf("Insufficient gzip buffer.\n"); return; \
+  }
+
+void parallel_gzip_writer_add_text_qual(parallel_gzip_writer_t * pzwtr, char * text, int tlen, int thread_no){
+	CHECK_SIZE ;
+
+	int ii;
+	for(ii=0; ii<tlen; ii++){
+		int nch = text[ii];
+		if(nch >'/') nch--;
+		tho -> in_buffer[tho -> in_buffer_used +ii] = nch;
 	}
+	tho -> in_buffer_used += tlen;
+}
+void parallel_gzip_writer_add_text(parallel_gzip_writer_t * pzwtr, char * text, int tlen, int thread_no){
+	CHECK_SIZE ;
+
 	memcpy(tho -> in_buffer + tho -> in_buffer_used, text, tlen);
 	tho -> in_buffer_used += tlen;
 }
@@ -757,7 +783,8 @@ int parallel_gzip_writer_add_read_fqs_scRNA(parallel_gzip_writer_t**outfps, char
 	int reclen=0;
 	parallel_gzip_writer_t * outR1fp = outfps[0];
 	parallel_gzip_writer_t * outI1fp = outfps[1];
-	parallel_gzip_writer_t * outR2fp = outfps[2];
+	parallel_gzip_writer_t * outI2fp = outfps[2];
+	parallel_gzip_writer_t * outR2fp = outfps[3];
 
 	memcpy(&reclen, bambin,4);
 	int flag = 0, l_seq = 0, l_read_name = 0, n_cigar_ops = 0;
@@ -771,32 +798,50 @@ int parallel_gzip_writer_add_read_fqs_scRNA(parallel_gzip_writer_t**outfps, char
 	parallel_gzip_writer_add_text(outR2fp,"@",1,thread_no);
 	parallel_gzip_writer_add_text(outR1fp,"@",1,thread_no);
 	parallel_gzip_writer_add_text(outI1fp,"@",1,thread_no);
+	if(outI2fp) parallel_gzip_writer_add_text(outI2fp,"@",1,thread_no);
 	char * readname = bambin+36;
 	parallel_gzip_writer_add_text(outR1fp,readname, 12,thread_no);
 	parallel_gzip_writer_add_text(outR2fp,readname, 12,thread_no);
 	parallel_gzip_writer_add_text(outI1fp,readname, 12,thread_no);
+	if(outI2fp) parallel_gzip_writer_add_text(outI2fp,readname, 12,thread_no);
+
 	parallel_gzip_writer_add_text(outR1fp,"\n",1,thread_no);
 	parallel_gzip_writer_add_text(outR2fp,"\n",1,thread_no);
 	parallel_gzip_writer_add_text(outI1fp,"\n",1,thread_no);
+	if(outI2fp) parallel_gzip_writer_add_text(outI2fp,"\n",1,thread_no);
 
+	//SUBREADprintf("WRITEFQ RNAME '%s'\n", bambin+36);
 	char * R1seq = bambin+36+13;
 	int R1len = 0;
 	for(R1len=0; R1seq[R1len] && R1seq[R1len]!='|' ;R1len++);
 	char * R1qual = R1seq + R1len + 1;
 	parallel_gzip_writer_add_text(outR1fp,R1seq, R1len,thread_no);
 	parallel_gzip_writer_add_text(outR1fp,"\n+\n",3,thread_no);
-	parallel_gzip_writer_add_text(outR1fp,R1qual, R1len,thread_no);
+	parallel_gzip_writer_add_text_qual(outR1fp,R1qual, R1len,thread_no);
 	parallel_gzip_writer_add_text(outR1fp,"\n",1,thread_no);
 
 	char * I1seq = R1qual + R1len + 1;
-	int I1len = 0;
-	for(I1len=0; I1seq[I1len] && I1seq[I1len]!='|' ;I1len++);
-	char * I1qual = I1seq + I1len + 1;
+	int I1I2len = 0;
+	for(I1I2len=0; I1seq[I1I2len] && I1seq[I1I2len]!='|' ;I1I2len++);
+	int I1len = I1I2len;
+	if(outI2fp) I1len /=2;
+
+	char * I2seq = I1seq + I1len;
+	char * I1qual = I1seq + I1I2len + 1;
+	char * I2qual = I1seq + I1I2len + I1len + 1;
+
 	parallel_gzip_writer_add_text(outI1fp,I1seq, I1len,thread_no);
 	parallel_gzip_writer_add_text(outI1fp,"\n+\n",3,thread_no);
-	parallel_gzip_writer_add_text(outI1fp,I1qual, I1len,thread_no);
+	parallel_gzip_writer_add_text_qual(outI1fp,I1qual, I1len,thread_no);
 	parallel_gzip_writer_add_text(outI1fp,"\n",1,thread_no);
 
+	if(outI2fp){
+		parallel_gzip_writer_add_text(outI2fp,I2seq, I1len,thread_no);
+		parallel_gzip_writer_add_text(outI2fp,"\n+\n",3,thread_no);
+		parallel_gzip_writer_add_text_qual(outI2fp,I2qual, I1len,thread_no);
+		parallel_gzip_writer_add_text(outI2fp,"\n",1,thread_no);
+	}
+
 	char oseq[l_seq+1];
 	int seqbase = 36+l_read_name+n_cigar_ops*4;
 	for(x1=0; x1<l_seq;x1++)oseq[x1]="=ACMGRSVTWYHKDBN"[(bambin[ seqbase+(x1/2)] >> (((x1%2)?0:1) *4) )&0xf];
