@@ -36,9 +36,10 @@ $SH_CMD data/compare.sh data/test-junc.sam data/corner-Fraction.ora data/test-mi
 $SH_CMD data/compare.sh data/corner-fractions.sam data/corner-fractions.ora data/corner-fractions.SAF "  -O -M -F SAF --fraction  " "Advanced fractions"
 $SH_CMD data/compare.sh data/test-junc.sam data/corner-Jcounts.ora data/test-minimum.SAF "-p --countReadPairs -F SAF -J " "Junction counting" JC
 
-if test -f /usr/local/work/work/liao/subread/chromosomes/all_34_alt.fa
+faf=~/prj/Common/Indexes/Subread/hg19/hg19.fa.gz
+if test -f $faf 
 then
-	$SH_CMD data/compare.sh data/test-junc.sam data/corner-Jcounts-FA.ora data/test-minimum.SAF "-p --countReadPairs -F SAF -J --genome /usr/local/work/work/liao/subread/chromosomes/all_34_alt.fa " "Junction counting (with genome) " JC
+	$SH_CMD data/compare.sh data/test-junc.sam data/corner-Jcounts-FA.ora data/test-minimum.SAF "-p --countReadPairs -F SAF -J --genome $faf " "Junction counting (with genome) " JC
 else
 	echo "Skipping Junction counting (with genome)."
 fi
